<?php
/**
 * @file
 * Gamertag Plugin: Provides Nintendo 3DS Gamertags.
 */

class gamertags_3ds extends gamertags {
  /**
   * Return information about this platform.
   *
   * @return
   *   #machine_name: Machine-name of this platform, should match the class name; "xbox" for "gamertags_xbox"
   *   #title: Human-readable title for administrative displays
   *   #description: (optional) Human-readable description for administrative displays
   */
  static public function getInfo() {
    return array(
      '#machine_name' => '3ds',
      '#title' => t('3DS Gamertags'),
      '#description' => t('Nintendo 3DS Friend Code'),
    );
  }

  /**
   * Return filter information about this platform.
   *
   * @return
   *   short: Human-readable short description for filter tips
   *   long: Human-readable long description for filter tips
   */
  static public function filterInfo() {
    return array(
      'short' => '[3ds:id]',
      'long' => t('Nintendo 3DS Gamertag by typing [3ds:id]'),
    );
  }

  /**
   * Return token information about this platform.
   *
   * @return
   *   array containing token information where the key is a machine-name and the value
   *   a description of the token output
   */
  static public function tokenList() {
    return array(
      'user-gamertag-3ds' => t('Corresponding Nintendo 3DS Gamertag for this user.'),
      'user-gamertag-3ds-text' => t('Corresponding Nintendo 3DS Gamertag for this user (as plain text).'),
    );
  }

  /**
   * Return token values for this platform.
   *
   * @return
   *   array containing token values where the key is a machine-name and the value
   *   contains themed gamertag output
   */
  static public function tokenValues(stdClass $account) {
    return array(
      'user-gamertag-3ds' => self::render($account, __CLASS__),
      'user-gamertag-3ds-text' => check_plain($account->gamertags_3ds),
    );
  }

  /**
   * Extends hook_user_view().
   */
  public function userView(stdClass &$account) {
    $account->content['summary']['gamertags_3ds_view'] = array(
      '#type' => 'user_profile_item',
      '#title' => t('3DS Friend Code'),
      '#value' => self::render($account, __CLASS__),
      '#weight' => (int) variable_get('gamertags_3ds_weight', 0),
    );
  }

  /**
   * Extends hook_user_form().
   */
  public function userForm(stdClass $account) {
    return array(
      'gamertags_3ds' => array(
        '#type' => 'textfield',
        '#title' => t('Nintendo 3DS'),
        '#default_value' => isset($account->gamertags_3ds) ? $account->gamertags_3ds : '',
        '#description' => t('If you have one, please enter your 3DS Friend Code.'),
        '#weight' => (int) variable_get('gamertags_3ds_weight', 0),
      ),
    );
  }

  /**
   * Validation for userForm().
   */
  function userFormValidate(&$values) {
    if (($three_ds_gamertag = preg_replace(array("/\s+/", "/-+/"), "", $values['gamertags_3ds'])) && (!preg_match("/^[0-9]+$/", $three_ds_gamertag) || drupal_strlen($three_ds_gamertag) != 12)) {
      form_set_error('gamertags_3ds', t('3DS Friend Codes can be 12 digit numbers only.'));
    }
    // For fun, let's format all 3ds friendcodes so they look like this 1234-1234-1234.
    if (!empty($three_ds_gamertag)) {
      $values['gamertags_3ds'] = preg_replace("/([0-9]{4})([0-9]{4})([0-9]{4})/", "$1-$2-$3", $three_ds_gamertag);
    }
  }

  public function adminUrlSettings() { return array(); }

  /**
   * Extends hook_theme().
   */
  public function theme() {
    return array(
      'arguments' => array(
        'gamertag' => NULL,
      ),
      'template' => 'platforms/nintendo/3ds/gamertags.3ds',
      'file' => 'platforms/nintendo/3ds/gamertags.3ds.inc',
    );
  }

  /**
   * Provides values for SimpleTest.
   */
  public function _testContent(&$edit, $calling_class) {
    $edit['gamertags_3ds'] = '111111111111';
  }
}

/**
 * Preprocess function for gamertags_3ds theme function.
 */
function gamertags_preprocess_gamertags_3ds(&$variables) {
  drupal_add_css(drupal_get_path('module', 'gamertags') .'/platforms/nintendo/3ds/gamertags.3ds.css');
  $variables['gamertag'] = check_plain($variables['gamertag']);
}
